
# coding utf-8
import pytest

from ladybug_comfort.di import discomfort_index, discomfort_index_effect_category


def test_discomfort_index():
    """Test the discomfort_index function."""
    assert discomfort_index(32, 85) == pytest.approx(30.55625, rel=1e-3)
    assert discomfort_index(20, 50) == pytest.approx(18.4875, rel=1e-3)

    assert discomfort_index_effect_category(35) == 3
    assert discomfort_index_effect_category(28) == 2
    assert discomfort_index_effect_category(25) == 1
    assert discomfort_index_effect_category(18) == 0
    assert discomfort_index_effect_category(14) == -1
    assert discomfort_index_effect_category(10) == -2
    assert discomfort_index_effect_category(-5) == -3
    assert discomfort_index_effect_category(-15) == -4
    assert discomfort_index_effect_category(-21) == -5
    assert discomfort_index_effect_category(-45) == -6



# coding utf-8
import pytest

from ladybug_comfort.humidex import humidex, humidex_degree_of_comfort


def test_humidex():
    """Test the humidex function."""
    assert humidex(22, 15) == pytest.approx(25.96900, rel=1e-3)
    assert humidex(20, 20) == pytest.approx(27.56977, rel=1e-3)
    assert humidex(28, 20) == pytest.approx(35.56977, rel=1e-3)
    assert humidex(28, 26) == pytest.approx(41.45899, rel=1e-3)
    assert humidex(34, 25) == pytest.approx(46.33840, rel=1e-3)


def test_humidex_degree_of_comfort():
    """Test the humidex degree of comfort thresholds"""
    assert humidex_degree_of_comfort(0.0) == 0
    assert humidex_degree_of_comfort(19.0) == 0
    assert humidex_degree_of_comfort(19.9) == 0
    assert humidex_degree_of_comfort(20.0) == 1
    assert humidex_degree_of_comfort(29.9) == 1
    assert humidex_degree_of_comfort(30.0) == 2
    assert humidex_degree_of_comfort(39.9) == 2
    assert humidex_degree_of_comfort(40.0) == 3
    assert humidex_degree_of_comfort(45.9) == 3
    assert humidex_degree_of_comfort(46.0) == 4
    assert humidex_degree_of_comfort(50.0) == 4
